@@ -16,7 +16,7 @@
     <message>
         <location filename="../passworddialog.ui" line="45"/>
         <source>&amp;Copy</source>
-        <translation>複製 (&amp;C)</translation>
+        <translation>複製(&amp;C)</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="83"/>
@@ -26,7 +26,7 @@
     <message>
         <location filename="../passworddialog.ui" line="106"/>
         <source>LXQt sudo backend</source>
-        <translation>LXQt sudo後端</translation>
+        <translation>LXQt sudo 後端</translation>
     </message>
     <message>
         <location filename="../passworddialog.ui" line="109"/>
@@ -57,10 +57,10 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../sudo.cpp" line="75"/>
+        <location filename="../sudo.cpp" line="78"/>
         <source>Usage: %1 option [command [arguments...]]
 
-GUI frontend for %2/%3
+GUI frontend for %2/%3/%4
 
 Arguments:
   option:
@@ -68,27 +68,15 @@ Arguments:
     -v|--version   Print version information.
     -s|--su        Use %3(1) as backend.
     -d|--sudo      Use %2(8) as backend.
+    -a|--doas      Use %4(1) as backend.
   command          Command to run.
   arguments        Optional arguments for command.
 
 </source>
-        <translation>使用方式：%1 選項 [指令 [參數...]]
-
-GUI 前端 %2/%3
-
-參數：
-  選項：
-    -h|--help     顯示此幫助訊息。
-    -v|--version  顯示版本訊息。
-    -s|--su       使用 %3(1) 當後端。
-    -d|--sudo     使用 %2(8) 當後端。
-  指令            要執行的指令。
-  參數            可選的指令參數。
-
-</translation>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="92"/>
+        <location filename="../sudo.cpp" line="96"/>
         <source>%1 version %2
 </source>
         <translation>%1 版本 %2
@@ -98,55 +86,55 @@ GUI 前端 %2/%3
 <context>
     <name>Sudo</name>
     <message>
-        <location filename="../sudo.cpp" line="195"/>
+        <location filename="../sudo.cpp" line="205"/>
         <source>%1: no command to run provided!</source>
         <translation>%1：沒有可執行的指令！</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="202"/>
+        <location filename="../sudo.cpp" line="212"/>
         <source>%1: no backend chosen!</source>
         <translation>%1：沒有選擇後端！</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="219"/>
+        <location filename="../sudo.cpp" line="229"/>
         <source>Syscall error, failed to fork: %1</source>
-        <translation>系統調用錯誤，復刻%1失敗</translation>
+        <translation>系統呼叫錯誤，複刻引用失敗：%1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="246"/>
+        <location filename="../sudo.cpp" line="257"/>
         <source>unset</source>
         <extracomment>shouldn&apos;t be actually used but keep as short as possible in translations just in case.</extracomment>
-        <translation>復原</translation>
+        <translation>尚未設定</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="295"/>
+        <location filename="../sudo.cpp" line="323"/>
         <source>%1: Detected attempt to inject privileged command via LC_ALL env(%2). Exiting!
 </source>
-        <translation>%1：檢測到嘗試通過LC_ALL env（％2）注入特權命令。退出！
+        <translation>%1：檢測到嘗試經由 LC_ALL env(％2) 注入特權指令。退出中！
 </translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="337"/>
+        <location filename="../sudo.cpp" line="365"/>
         <source>Syscall error, failed to bring pty to non-block mode: %1</source>
-        <translation>系統調用錯誤，無法將pty調整為非區塊模式：%1</translation>
+        <translation>系統呼叫錯誤，無法將 pty 帶入非阻擋模式：%1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="345"/>
+        <location filename="../sudo.cpp" line="373"/>
         <source>Syscall error, failed to fdopen pty: %1</source>
-        <translation>系統調用錯誤，開啓(fdopen) pty失敗：%1</translation>
+        <translation>系統呼叫錯誤，開啓 pty 失敗： %1</translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="314"/>
+        <location filename="../sudo.cpp" line="342"/>
         <source>%1: Failed to exec &apos;%2&apos;: %3
 </source>
         <translation>%1：執行 &apos;%2&apos; 失敗：%3
 </translation>
     </message>
     <message>
-        <location filename="../sudo.cpp" line="376"/>
+        <location filename="../sudo.cpp" line="407"/>
         <source>Child &apos;%1&apos; process failed!
 %2</source>
-        <translation>子執行序&apos;%1&apos;執行失敗！
+        <translation>分支 &apos;%1&apos; 程序失敗！
 %2</translation>
     </message>
 </context>
